@@ -102,10 +102,10 @@ protected:
     memory_desc_t src_md_;
     memory_desc_t dst_md_;
 
-    eltwise_pd_t(const eltwise_desc_t *adesc, const primitive_attr_t *attr,
+    eltwise_pd_t(const op_desc_t *adesc, const primitive_attr_t *attr,
             const eltwise_fwd_pd_t *hint_fwd_pd)
         : primitive_desc_t(attr, base_pkind)
-        , desc_(*adesc)
+        , desc_(*op_desc_t::to_desc<eltwise_desc_t>(adesc))
         , hint_fwd_pd_(hint_fwd_pd)
         , src_md_(desc_.src_desc)
         , dst_md_(desc_.dst_desc) {}
@@ -179,7 +179,7 @@ struct eltwise_fwd_pd_t : public eltwise_pd_t {
     }
 
 protected:
-    eltwise_fwd_pd_t(const eltwise_desc_t *adesc, const primitive_attr_t *attr,
+    eltwise_fwd_pd_t(const op_desc_t *adesc, const primitive_attr_t *attr,
             const eltwise_fwd_pd_t *hint_fwd_pd)
         : eltwise_pd_t(adesc, attr, hint_fwd_pd) {}
 
@@ -281,7 +281,7 @@ protected:
     memory_desc_t diff_src_md_;
     memory_desc_t diff_dst_md_;
 
-    eltwise_bwd_pd_t(const eltwise_desc_t *adesc, const primitive_attr_t *attr,
+    eltwise_bwd_pd_t(const op_desc_t *adesc, const primitive_attr_t *attr,
             const eltwise_fwd_pd_t *hint_fwd_pd)
         : eltwise_pd_t(adesc, attr, hint_fwd_pd)
         , diff_src_md_(desc_.diff_src_desc)
