@@ -32,6 +32,7 @@
 #include "cpu/binary_injector_utils.hpp"
 #include "cpu/x64/cpu_isa_traits.hpp"
 #include "cpu/x64/injectors/injector_utils.hpp"
+#include "cpu/x64/jit_avx512_core_fp8cvt.hpp"
 #include "cpu/x64/jit_generator.hpp"
 
 namespace dnnl {
@@ -42,6 +43,8 @@ namespace binary_injector {
 using dnnl::impl::cpu::binary_injector_utils::get_src1_desc;
 using dnnl::impl::cpu::binary_injector_utils::prepare_binary_args;
 
+bcast_set_t get_all_strategies_supported_by_injector();
+
 bool binary_args_broadcast_supported(const post_ops_t &post_ops,
         const memory_desc_wrapper &dst_d,
         const bcast_set_t &supported_strategy_set);
@@ -166,6 +169,11 @@ private:
  * object.
  */
 struct static_params_t {
+    static_params_t(const Xbyak::Reg64 &param1,
+            const bcast_set_t &supported_strategy_set,
+            const rhs_arg_static_params_t &rhs_arg_static_params,
+            fp8_emulation_e5m2_t *f8_e5m2_emu,
+            fp8_emulation_e4m3_t *f8_e4m3_emu);
     static_params_t(const Xbyak::Reg64 &param1,
             const bcast_set_t &supported_strategy_set,
             const rhs_arg_static_params_t &rhs_arg_static_params);
@@ -175,6 +183,10 @@ struct static_params_t {
     Xbyak::Reg64 param1;
     const bcast_set_t supported_strategy_set;
     rhs_arg_static_params_t rhs_arg_static_params;
+    // Both fp8 (e5m2 and e4m3) binary post-ops data types are possible.
+    // Therefore, we need both fp8 emulators.
+    fp8_emulation_e5m2_t *f8_e5m2_emu_ {nullptr};
+    fp8_emulation_e4m3_t *f8_e4m3_emu_ {nullptr};
 };
 
 /*
@@ -350,6 +362,19 @@ private:
             const std::size_t offset, const Xbyak::Reg64 &tmp_reg,
             std::size_t elem_size_bytes) const;
 
+    void append_oc_d_offset(
+            const std::map<int, Xbyak::Address> &vmm_idx_to_out_addr,
+            const std::map<int, Xbyak::Reg64> &vmm_idx_to_out_reg,
+            const std::map<int, size_t> &vmm_idx_to_out_elem_off_val,
+            int vmm_idx, const Xbyak::Reg64 &addr_reg,
+            const Xbyak::Reg64 &tmp_reg, std::size_t elem_size_bytes,
+            bool is_first) const;
+    void calculate_oc_d_ncsp_base(
+            const dim_t *strides, const Xbyak::Reg64 &tmp_reg) const;
+    void calculate_oc_d_ncsp_partial(const dim_t *strides,
+            const std::size_t offset, const Xbyak::Reg64 &tmp_reg,
+            std::size_t elem_size_bytes) const;
+
     void append_mb_sp_offset(
             const std::map<int, Xbyak::Address> &vmm_idx_to_out_addr,
             const std::map<int, Xbyak::Reg64> &vmm_idx_to_out_reg,
@@ -573,6 +598,8 @@ private:
     Xbyak::Opmask get_aux_kmask() const;
 
     jit_generator *host_;
+    fp8_emulation_e5m2_t *f8_e5m2_emu_ {nullptr};
+    fp8_emulation_e4m3_t *f8_e4m3_emu_ {nullptr};
     const rhs_arg_static_params_t rhs_arg_static_params_;
     const Xbyak::Reg64 param1_;
     const bcast_set_t supported_strategy_set_;
